"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const minimist_1 = tslib_1.__importDefault(require("minimist"));
const version_1 = require("./version");
class Command {
    constructor(commandConfig) {
        this.description = commandConfig.description;
        this.runCallback = commandConfig.runCallback;
        this.getHelpBody = commandConfig.getHelpBody;
        this.minimistConfig = commandConfig.minimistConfig;
    }
    run(args) {
        const argv = minimist_1.default(args, this.minimistConfig);
        // Check if we got passed help
        if (argv.help) {
            this.help();
            return;
        }
        if (argv.version) {
            this.version();
            return;
        }
        this.runCallback(argv);
    }
    version() {
        const versionMessage = `wasmer-js ${version_1.getVersion()}`;
        console.log(versionMessage);
    }
    help() {
        let helpMessage = `wasmer-js ${version_1.getVersion()}
${this.description}`;
        const helpBody = this.getHelpBody();
        if (helpBody !== undefined) {
            helpMessage = `${helpMessage} 

${helpBody}`;
        }
        console.log(helpMessage);
    }
}
exports.Command = Command;
