"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const minimist_1 = tslib_1.__importDefault(require("minimist"));
const run_1 = require("./commands/run");
const version_1 = require("./version");
// Define our base help command
const printHelp = () => {
    console.log(`wasmer-js ${version_1.getVersion()}
The Wasmer Engineering Team <engineering@wasmer.io>
Node.js Wasm execution runtime.

USAGE:
    wasmer <SUBCOMMAND>

FLAGS:
    -h, --help       Prints help information
    -V, --version    Prints version information

SUBCOMMANDS:
    help           Prints this message or the help of the given subcommand(s)
    run            Run a WebAssembly file. Formats accepted: wasm, wat
    validate       Validate a Web Assembly binary`);
};
const printVersion = () => {
    console.log(`wasmer-js ${version_1.getVersion()}`);
};
// Use minimist to parse recognized flags and arguments
const argv = minimist_1.default(process.argv.slice(2), {
    boolean: ["help", "version"],
    alias: {
        help: ["h"],
        version: ["V"]
    }
});
const run = () => {
    // Check if we have the version  flag
    if (argv.version) {
        printVersion();
        return;
    }
    // Check if we have any arguments
    if (argv._.length === 0) {
        printHelp();
        return;
    }
    // Get our subcommand
    const subcommand = argv._.shift();
    // Split our arguments into args and flags
    const args = argv._.slice(0);
    const flags = Object.assign({}, argv);
    delete flags._;
    // Call our correct subcommand
    if (subcommand === "run") {
        run_1.runCommand.run(process.argv.slice(3));
        return;
    }
    // Do "run" as the default subcommand
    run_1.runCommand.run(process.argv.slice(2));
};
run();
